#[non_exhaustive]pub enum LandMode {
NoLanding,
AfterApproval,
BeforeReview,
Unknown,
}Expand description
When a reviewed call allows its builder to land.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoLanding
Not in this job.
AfterApproval
In one extra builder turn after an approving verdict.
BeforeReview
In each round’s builder turn, before that round’s review.
Unknown
A mode this client does not know, from a newer server.