pub enum ProjectPhase {
Discovery,
Planning,
Implementation,
Verification,
Staging,
Production,
Reporting,
}Expand description
The lifecycle phase observed for a durable project.
Variants
Discovery
The project has been created and is being understood.
Planning
Tasks and dependencies are being prepared.
Implementation
One or more implementation tasks are running.
Verification
Work is being checked or has failed a run.
Staging
Work is ready for staging.
Production
Work has been released to production.
Reporting
The project is being reported or closed.