job_agent

Function job_agent 

pub fn job_agent<'a>(agent: &'a str, tool: &'a str) -> &'a str
The agent a background job runs, such as codex: agent when it is set, otherwise what follows agent_ in the delegating tool, as SCV 0.3.0 and older named it (agent_codex), otherwise tool itself.